Exception: Decidim::Verifications::InvalidVerificationRoute
- Inherits:
-
StandardError
- Object
- StandardError
- Decidim::Verifications::InvalidVerificationRoute
- Defined in:
- lib/decidim/verifications/adapter.rb
Instance Method Summary collapse
-
#initialize(route:) ⇒ InvalidVerificationRoute
constructor
A new instance of InvalidVerificationRoute.
Constructor Details
#initialize(route:) ⇒ InvalidVerificationRoute
Returns a new instance of InvalidVerificationRoute.
6 7 8 9 10 11 12 13 14 |
# File 'lib/decidim/verifications/adapter.rb', line 6 def initialize(route:) msg = <<~MSG You specified a direct handler but you are trying to use `#{route}` which is only available for multi-step authorization workflows. Change your workflow to define an engine with a `#{route}` route. MSG super(msg) end |