Class: Decidim::Verifications::AdminLog::CsvDatumPresenter
- Inherits:
-
Log::BasePresenter
- Object
- Log::BasePresenter
- Decidim::Verifications::AdminLog::CsvDatumPresenter
- Defined in:
- app/presenters/decidim/verifications/admin_log/csv_datum_presenter.rb
Overview
This class holds the logic to present a ‘Decidim::Verifications::CsvDatum for the `AdminLog` log.
Usage should be automatic and you should not need to call this class directly, but here is an example:
action_log = Decidim::ActionLog.last
view_helpers # => this comes from the views
CsvDatumPresenter.new(action_log, view_helpers).present
Instance Method Summary collapse
-
#initialize(action_log, view_helpers) ⇒ CsvDatumPresenter
constructor
A new instance of CsvDatumPresenter.
Constructor Details
#initialize(action_log, view_helpers) ⇒ CsvDatumPresenter
Returns a new instance of CsvDatumPresenter.
16 17 18 19 |
# File 'app/presenters/decidim/verifications/admin_log/csv_datum_presenter.rb', line 16 def initialize(action_log, view_helpers) super @resource = action_log.resource end |